@@ -1,13 +1,14 @@
 # Pod::Text::Color -- Convert POD data to formatted color ASCII text
 #
-# Copyright 1999, 2001, 2004, 2006, 2008, 2009 Russ Allbery <rra@stanford.edu>
-#
-# This program is free software; you may redistribute it and/or modify it
-# under the same terms as Perl itself.
-#
 # This is just a basic proof of concept.  It should later be modified to make
 # better use of color, take options changing what colors are used for what
 # text, and the like.
+#
+# Copyright 1999, 2001, 2004, 2006, 2008, 2009, 2014
+#     Russ Allbery <rra@cpan.org>
+#
+# This program is free software; you may redistribute it and/or modify it
+# under the same terms as Perl itself.
 
 ##############################################################################
 # Modules and declarations
@@ -15,17 +16,18 @@
 
 package Pod::Text::Color;
 
-require 5.004;
+use 5.006;
+use strict;
+use warnings;
 
 use Pod::Text ();
 use Term::ANSIColor qw(colored);
 
-use strict;
 use vars qw(@ISA $VERSION);
 
 @ISA = qw(Pod::Text);
 
-$VERSION = '2.05';
+$VERSION = '4.00';
 
 ##############################################################################
 # Overrides
@@ -143,11 +145,11 @@ Perl core distribution as of 5.6.0.
 
 =head1 AUTHOR
 
-Russ Allbery <rra@stanford.edu>.
+Russ Allbery <rra@cpan.org>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 1999, 2001, 2004, 2006, 2008, 2009 Russ Allbery <rra@stanford.edu>.
+Copyright 1999, 2001, 2004, 2006, 2008, 2009 Russ Allbery <rra@cpan.org>.
 
 This program is free software; you may redistribute it and/or modify it
 under the same terms as Perl itself.
