@@ -1,14 +1,14 @@
 # Pod::Text::Termcap -- Convert POD data to ASCII text with format escapes.
 #
-# Copyright 1999, 2001, 2002, 2004, 2006, 2008, 2009
-#     Russ Allbery <rra@stanford.edu>
-#
-# This program is free software; you may redistribute it and/or modify it
-# under the same terms as Perl itself.
-#
 # This is a simple subclass of Pod::Text that overrides a few key methods to
 # output the right termcap escape sequences for formatted text on the current
 # terminal type.
+#
+# Copyright 1999, 2001, 2002, 2004, 2006, 2008, 2009, 2014
+#     Russ Allbery <rra@cpan.org>
+#
+# This program is free software; you may redistribute it and/or modify it
+# under the same terms as Perl itself.
 
 ##############################################################################
 # Modules and declarations
@@ -16,18 +16,19 @@
 
 package Pod::Text::Termcap;
 
-require 5.004;
+use 5.006;
+use strict;
+use warnings;
 
 use Pod::Text ();
 use POSIX ();
 use Term::Cap;
 
-use strict;
 use vars qw(@ISA $VERSION);
 
 @ISA = qw(Pod::Text);
 
-$VERSION = '2.05';
+$VERSION = '4.00';
 
 ##############################################################################
 # Overrides
@@ -104,7 +105,7 @@ sub strip_format {
     return $text;
 }
 
-# Override the wrapping code to igore the special sequences.
+# Override the wrapping code to ignore the special sequences.
 sub wrap {
     my $self = shift;
     local $_ = shift;
@@ -113,7 +114,7 @@ sub wrap {
     my $width = $$self{opt_width} - $$self{MARGIN};
 
     # $codes matches a single special sequence.  $char matches any number of
-    # special sequences preceeding a single character other than a newline.
+    # special sequences preceding a single character other than a newline.
     # We have to do $shortchar and $longchar in variables because the
     # construct ${char}{0,$width} didn't do the right thing until Perl 5.8.x.
     my $codes = "(?:\Q$$self{BOLD}\E|\Q$$self{UNDL}\E|\Q$$self{NORM}\E)";
@@ -182,12 +183,12 @@ Perl core distribution as of 5.6.0.
 
 =head1 AUTHOR
 
-Russ Allbery <rra@stanford.edu>.
+Russ Allbery <rra@cpan.org>.
 
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 1999, 2001, 2002, 2004, 2006, 2008, 2009 Russ Allbery
-<rra@stanford.edu>.
+<rra@cpan.org>.
 
 This program is free software; you may redistribute it and/or modify it
 under the same terms as Perl itself.
